pub enum Event<T: Config> {
ElectionAttemptFailed {
session: SessionIndex,
error: DispatchError,
runner: AuthorOf<T>,
},
ElectedInstance {
session: SessionIndex,
runner: AuthorOf<T>,
},
RewardInitiated {
author: AuthorOf<T>,
value: AssetOf<T>,
},
RewardFailed {
author: AuthorOf<T>,
error: DispatchError,
},
PenaltyInitiated {
author: AuthorOf<T>,
penalty: PenaltyRatio,
},
PenaltyFailed {
author: AuthorOf<T>,
error: DispatchError,
},
AffidavitSubmitted {
afdt_id: AffidavitId<T>,
session: SessionIndex,
},
ValidationBegins {
author: AuthorOf<T>,
for_session: SessionIndex,
},
ChillingBegins {
author: AuthorOf<T>,
for_session: SessionIndex,
},
GenesisConfigUpdated(ForceGenesisConfig<T>),
// some variants omitted
}Expand description
The Event enum of this pallet
Variants
ElectionAttemptFailed
Emitted when an election attempt fails.
ElectedInstance
Emitted after a successful election instance.
RewardInitiated
Emitted after a reward is successfully delegated to be
applied to an author via CompensateRoles.
RewardFailed
Emitted when rewarding an author via CompensateRoles fails.
PenaltyInitiated
Emitted after a penalty is successfully delegated to be
applied to an author via CompensateRoles.
PenaltyFailed
Emitted when applying a penalty to an author via
CompensateRoles fails.
AffidavitSubmitted
Emitted after a successful affidavit submission for the election to be conducted for the upcoming session.
ValidationBegins
Emitted when an author successfully declares their affidavit signing key for the next session
ChillingBegins
Emitted when an author successfully initiates the chilling process by removing their affidavit key for a future session.
GenesisConfigUpdated(ForceGenesisConfig<T>)
A genesis config parameter was updated forcefully.