Type Alias AffidavitBeginsAt

pub type AffidavitBeginsAt<T: Config> = StorageValue<_GeneratedPrefixForStorageAffidavitBeginsAt<T>, Duration, ValueQuery>;
Start of affidavit submission window as a percentage ([PerThing]) of the current session. Authors submit affidavits for the next upcoming session starting from this point.

Examples

  • If the current session is 1000 blocks long and AffidavitBeginsAt = 20%, affidavit submissions can start at block 200 of the current session.
  • Authors cannot submit affidavits before this block, even if they are ready.

Storage type is [StorageValue] with value type Duration.

Aliased Type

pub struct AffidavitBeginsAt<T: Config>(/* private fields */);