pub type ElectionTxPriority<T: Config> = StorageValue<_GeneratedPrefixForStorageElectionTxPriority<T>, TransactionPriority, ValueQuery>;Expand description
Transaction priority for the Pallet::elect extrinsic.
This extrinsic is submitted locally by an offchain worker and not propagated to other peers via the transaction pool.
The priority therefore only affects local block construction and ordering relative to other locally submitted transactions.
Storage type is [StorageValue] with value type TransactionPriority.
Aliased Type
pub struct ElectionTxPriority<T: Config>(/* private fields */);