pub type AffidavitEndsAt<T: Config> = StorageValue<_GeneratedPrefixForStorageAffidavitEndsAt<T>, Duration, ValueQuery>;Expand description
End of affidavit submission window as a percentage ([PerThing]) of the
current session.
Authors must submit affidavits before this block, leaving room for the election process for the next upcoming session.
Examples
- If the current session is 100 blocks long and
AffidavitEndsAt = 80%, affidavit submissions must end by block800. - The period from
AffidavitBeginsAttoAffidavitEndsAtdefines the affidavit submission window. - Elections for the next session should be conducted before this period ends.
Storage type is [StorageValue] with value type Duration.
Aliased Type
pub struct AffidavitEndsAt<T: Config>(/* private fields */);