pub type ElectionBeginsAt<T: Config> = StorageValue<_GeneratedPrefixForStorageElectionBeginsAt<T>, Duration, ValueQuery>;Expand description
Start of the election window as a percentage ([PerThing]) of the affidavit
submission period in the current session.
This does not refer to a percentage of the full session, but rather the relative position within the affidavit submission window. Authors submit affidavits first, then after this point, the election process can start.
Examples
- Suppose the affidavit window spans blocks 200-800 (
AffidavitBeginsAt = 20%,AffidavitEndsAt = 80%in a 100-block session). - If
ElectionBeginsAt = 50%, then the election starts halfway through the affidavit window: 200 + 50% * (800 - 200) = block 500. - Timeline:
- 200-500: affidavit submission period
- 500-800: election preparation
Storage type is [StorageValue] with value type Duration.
Aliased Type
pub struct ElectionBeginsAt<T: Config>(/* private fields */);