pub type ElectionRunnerPoints<T: Config> = StorageValue<_GeneratedPrefixForStorageElectionRunnerPoints<T>, T::Points, ValueQuery>;Expand description
Block points allocated for the election runner.
Determines how many Config::Points are required or suitable for an author
to act as the election runner in the upcoming session.
This value is used to assess election participation eligibility or priority.
Storage type is [StorageValue] with value type T :: Points.
Aliased Type
pub struct ElectionRunnerPoints<T: Config>(/* private fields */);